@@ -10,6 +10,7 @@ class Error(Exception):
     """ Base class for our own errors
 
     """
+
     def __init__(self, *args: Any) -> None:
         super().__init__(self, *args)
         self.message = " ".join(str(x) for x in args)
@@ -33,3 +34,8 @@ class InvalidConfig(Error):
 
     def __str__(self) -> str:
         return self.detailed_message
+
+
+class MissingRepo(Error):
+    def __init__(self, src: str):
+        super().__init__("No repo found in %s. Please run `tsrc sync`" % src)
