@@ -3,7 +3,9 @@ from tsrc.test.helpers.git_server import GitServer
 from cli_ui.tests import MessageRecorder
 
 
-def test_happy(tsrc_cli: CLI, git_server: GitServer, message_recorder: MessageRecorder) -> None:
+def test_happy(
+    tsrc_cli: CLI, git_server: GitServer, message_recorder: MessageRecorder
+) -> None:
     git_server.add_repo("foo")
     git_server.add_repo("spam")
     git_server.push_file("foo", "bar.txt", message="boring bar")
