@@ -2,24 +2,24 @@ from typing import Any
 import os
 from path import Path
 import pytest
+import cli_ui as ui
 
 import tsrc.cli.main
 
 
-class CLI():
+class CLI:
     def __init__(self) -> None:
         self.workspace_path = Path(os.getcwd())
 
     def run(self, *args: str, expect_fail: bool = False) -> None:
-        try:
-            tsrc.cli.main.main(args=args)
-            rc = 0
-        except SystemExit as e:
-            rc = e.code
-        if expect_fail and rc == 0:
-            assert False, "should have failed"
-        if rc != 0 and not expect_fail:
-            raise SystemExit(rc)
+        ui.info(">", ui.bold, "tsrc", *args, end="")
+        if expect_fail:
+            ui.info(ui.red, " (expecting failure)")
+            with pytest.raises(tsrc.Error):
+                tsrc.cli.main.testable_main(args)
+        else:
+            ui.info()
+            tsrc.cli.main.testable_main(args)
 
 
 @pytest.fixture
