@@ -1,6 +1,5 @@
 from typing import List, Optional
 import textwrap
-import os.path
 
 import ruamel.yaml
 
@@ -12,8 +11,6 @@ import pytest
 
 def test_load() -> None:
     contents = """
-gitlab:
-  url: http://gitlab.example.com
 repos:
   - src: foo
     url: git@example.com:foo.git
@@ -34,23 +31,21 @@ repos:
 """
     manifest = tsrc.Manifest()
     parsed = ruamel.yaml.safe_load(contents)
-    manifest.load(parsed)
-    assert manifest.gitlab
-    assert manifest.gitlab["url"] == "http://gitlab.example.com"
+    manifest.apply_config(parsed)
     assert manifest.get_repos() == [
         tsrc.Repo(
             remotes=[tsrc.repo.Remote(name="origin", url="git@example.com:foo.git")],
             src="foo",
             branch="next",
             sha1=None,
-            tag=None
+            tag=None,
         ),
         tsrc.Repo(
             remotes=[tsrc.repo.Remote(name="origin", url="git@example.com:bar.git")],
             src="bar",
             branch="master",
             sha1="ad2b68539c78e749a372414165acdf2a1bb68203",
-            tag=None
+            tag=None,
         ),
         tsrc.Repo(
             remotes=[tsrc.repo.Remote(name="origin", url="git@example.com:master.git")],
@@ -61,8 +56,8 @@ repos:
         ),
     ]
     assert manifest.copyfiles == [
-        (os.path.join("master", "top.cmake"), "CMakeLists.txt"),
-        (os.path.join("master", ".clang-format"), ".clang-format"),
+        tsrc.Copy("master", "top.cmake", "CMakeLists.txt"),
+        tsrc.Copy("master", ".clang-format", ".clang-format"),
     ]
 
 
@@ -77,7 +72,7 @@ repos:
 """
     manifest = tsrc.Manifest()
     parsed = ruamel.yaml.safe_load(contents)
-    manifest.load(parsed)
+    manifest.apply_config(parsed)
 
     def assert_clone_url(src: str, url: str) -> None:
         repo = manifest.get_repo(src)
@@ -101,11 +96,23 @@ repos:
 """
     manifest = tsrc.manifest.Manifest()
     parsed = ruamel.yaml.safe_load(contents)
-    manifest.load(parsed)
+    manifest.apply_config(parsed)
     one_repo = manifest.get_repo("foo")
     assert len(one_repo.remotes) == 1
 
 
+def test_no_url_and_no_remote(tmp_path: Path) -> None:
+    contents = """
+repos:
+  - src: foo
+    remotes: []
+"""
+    manifest_path = tmp_path / "manifest.yml"
+    manifest_path.write_text(contents)
+    with pytest.raises(tsrc.InvalidConfig):
+        tsrc.manifest.load(manifest_path)
+
+
 def assert_valid_schema(tmp_path: Path, contents: str) -> tsrc.manifest.Manifest:
     manifest_path = tmp_path / "manifest.yml"
     manifest_path.write_text(textwrap.dedent(contents))
@@ -133,9 +140,7 @@ def test_validates(tmp_path: Path) -> None:
             copy:
               - src: foo
                 dest: bar
-        gitlab:
-          url: foo
-        """
+        """,
     )
 
 
@@ -145,7 +150,7 @@ def test_allow_url(tmp_path: Path) -> None:
         """
           repos:
             - { src: bar, url: git@example.com/bar }
-         """
+         """,
     )
 
 
@@ -155,7 +160,7 @@ def test_allow_several_remotes(tmp_path: Path) -> None:
         """
           repos:
             - { src: bar, url: git@example.com/bar }
-          """
+          """,
     )
 
 
@@ -168,7 +173,7 @@ def test_disallow_url_and_remotes(tmp_path: Path) -> None:
             url: git@example.com/bar
             remotes:
             - { name: upstream, url: git@upstream.com/bar }
-        """
+        """,
     )
     assert "remotes" in error.message
     assert "url" in error.message
@@ -179,7 +184,9 @@ class ReposGetter:
         self.tmp_path = tmp_path
         self.contents = ""
 
-    def get_repos(self, groups: Optional[List[str]] = None, all_: bool = False) -> List[str]:
+    def get_repos(
+        self, groups: Optional[List[str]] = None, all_: bool = False
+    ) -> List[str]:
         manifest_path = self.tmp_path / "manifest.yml"
         manifest_path.write_text(self.contents)
         manifest = tsrc.manifest.load(manifest_path)
@@ -220,7 +227,11 @@ groups:
     repos: [linux1, linux2]
 """
     repos_getter.contents = contents
-    assert repos_getter.get_repos(groups=["default", "linux"]) == ["any", "linux1", "linux2"]
+    assert repos_getter.get_repos(groups=["default", "linux"]) == [
+        "any",
+        "linux1",
+        "linux2",
+    ]
 
 
 def test_inclusion(repos_getter: ReposGetter) -> None:
