@@ -1,4 +1,5 @@
 from typing import List, Tuple  # noqa
+import attr
 from path import Path
 import cli_ui as ui
 
@@ -11,10 +12,18 @@ class BadBranches(tsrc.Error):
     pass
 
 
+@attr.s(frozen=True)
+class RepoAtIncorrectBranchDescription:
+    src = attr.ib()  # type: str
+    actual = attr.ib()  # type: str
+    expected = attr.ib()  # type: str
+
+
 class Syncer(tsrc.executor.Task[tsrc.Repo]):
-    def __init__(self, workspace_path: Path) -> None:
+    def __init__(self, workspace_path: Path, *, force: bool = False) -> None:
         self.workspace_path = workspace_path
-        self.bad_branches = list()  # type: List[Tuple[str, str, str]]
+        self.bad_branches = []  # type: List[RepoAtIncorrectBranchDescription]
+        self.force = force
 
     def on_start(self, *, num_items: int) -> None:
         ui.info_1("Synchronizing workspace")
@@ -25,8 +34,8 @@ class Syncer(tsrc.executor.Task[tsrc.Repo]):
     def display_item(self, repo: tsrc.Repo) -> str:
         return repo.src
 
-    def process(self, repo: tsrc.Repo) -> None:
-        ui.info(repo.src)
+    def process(self, index: int, count: int, repo: tsrc.Repo) -> None:
+        ui.info_count(index, count, repo.src)
         repo_path = self.workspace_path / repo.src
         self.fetch(repo)
         ref = None
@@ -49,16 +58,22 @@ class Syncer(tsrc.executor.Task[tsrc.Repo]):
         except tsrc.Error:
             raise tsrc.Error("Not on any branch")
 
-        # FIXME: is repo.branch allowed to be None ?
         if current_branch and current_branch != repo.branch:
-            self.bad_branches.append((repo.src, current_branch, repo.branch))  # type: ignore
+            self.bad_branches.append(
+                RepoAtIncorrectBranchDescription(
+                    src=repo.src, actual=current_branch, expected=repo.branch
+                )
+            )
 
     def fetch(self, repo: tsrc.Repo) -> None:
         repo_path = self.workspace_path / repo.src
         for remote in repo.remotes:
             try:
                 ui.info_2("Fetching", remote.name)
-                tsrc.git.run(repo_path, "fetch", "--tags", "--prune", remote.name)
+                cmd = ["fetch", "--tags", "--prune", remote.name]
+                if self.force:
+                    cmd.append("--force")
+                tsrc.git.run(repo_path, *cmd)
             except tsrc.Error:
                 raise tsrc.Error("fetch from %s failed" % remote.name)
 
@@ -67,7 +82,7 @@ class Syncer(tsrc.executor.Task[tsrc.Repo]):
         ui.info_2("Resetting to", ref)
         status = tsrc.git.get_status(repo_path)
         if status.dirty:
-            raise tsrc.Error("%s dirty, skipping")
+            raise tsrc.Error("%s is dirty, skipping" % repo_path)
         try:
             tsrc.git.run(repo_path, "reset", "--hard", ref)
         except tsrc.Error:
@@ -87,8 +102,8 @@ class Syncer(tsrc.executor.Task[tsrc.Repo]):
         ui.error("Some projects were not on the correct branch")
         headers = ("project", "actual", "expected")
         data = [
-            ((ui.bold, name), (ui.red, actual), (ui.green, expected)) for
-            (name, actual, expected) in self.bad_branches
+            ((ui.bold, x.src), (ui.red, x.actual), (ui.green, x.expected))
+            for x in self.bad_branches
         ]
         ui.info_table(data, headers=headers)
         raise BadBranches()
